@@ -5,7 +5,7 @@ try:
 except ImportError:
     from django.contrib.gis.utils import GeoIP
 
-GEOIP_CACHE_METHOD = getattr(settings, 'GEOIP_CACHE_METHOD', GeoIP.GEOIP_INDEX_CACHE)
+GEOIP_CACHE_METHOD = getattr(settings, 'GEOIP_CACHE_METHOD', GeoIP.GEOIP_STANDARD)
 GEOIP_INCLUDE_TEMPLATE_TAGS = getattr(settings, 'GEOIP_INCLUDE_TEMPLATE_TAGS', False)
 
 if getattr(settings, 'GEOIP_DEBUG_DOMAIN_OR_IP', ''):
